# KMUHelper

![PyPI](https://img.shields.io/pypi/v/django-kmuhelper)
![PyPI - Django Version](https://img.shields.io/pypi/djversions/django-kmuhelper)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/django-kmuhelper)
![PyPI - License](https://img.shields.io/pypi/l/django-kmuhelper)

![GitHub code size in bytes](https://img.shields.io/github/languages/code-size/rafaelurben/django-kmuhelper)
![GitHub lines of code](https://img.shields.io/tokei/lines/github.com/rafaelurben/django-kmuhelper)
![GitHub issues](https://img.shields.io/github/issues/rafaelurben/django-kmuhelper)
![GitHub pull requests](https://img.shields.io/github/issues-pr/rafaelurben/django-kmuhelper)

Der KMUHelper ist, wie der Name schon sagt, ein Helfer für KMU, hauptsächlich für Schweizer, da der Hauptgrund für
die Entwicklung dieser Djangoapp die neue schweizer QR-Rechnung ist.

Diverse Infos über den KMUHelper gibt's auf der [Webseite](https://rafaelurben.github.io/kmuhelper/) sowie in der [Dokumentation](https://rafaelurben.github.io/django-kmuhelper/)

Bei Fragen oder Probleme bitte unbedingt [mich kontaktieren](https://rafaelurben.github.io/kmuhelper/kontakt) oder ein [Issue](https://github.com/rafaelurben/django-kmuhelper/issues) eröffnen!

## Installation

Siehe [hier](https://rafaelurben.github.io/django-kmuhelper/installation).
